==> mozilla-source-1.4a.tar.bz2: mozilla/content/xbl/src/nsXBLFormHandler.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Original Author: David W. Hyatt (hyatt@netscape.com)
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsCOMPtr.h"
#include "nsXBLPrototypeHandler.h"
#include "nsXBLFormHandler.h"
#include "nsIContent.h"
#include "nsIScriptContext.h"
#include "nsIScriptGlobalObject.h"
#include "nsIDocument.h"
#include "nsIDOMDocument.h"
#include "nsIEventListenerManager.h"
#include "nsIDOMEventReceiver.h"
#include "nsXBLBinding.h"
#include "nsIPrivateDOMEvent.h"
#include "nsIDOMWindowInternal.h"
#include "nsIServiceManager.h"
#include "nsIURI.h"
#include "nsXPIDLString.h"

PRUint32 nsXBLFormHandler::gRefCnt = 0;
nsIAtom* nsXBLFormHandler::kSubmitAtom = nsnull;
nsIAtom* nsXBLFormHandler::kResetAtom = nsnull;
nsIAtom* nsXBLFormHandler::kInputAtom = nsnull;
nsIAtom* nsXBLFormHandler::kSelectAtom = nsnull;
nsIAtom* nsXBLFormHandler::kChangeAtom = nsnull;

nsXBLFormHandler::nsXBLFormHandler(nsIDOMEventReceiver* aReceiver,
                                   nsXBLPrototypeHandler* aHandler)
  : nsXBLEventHandler(aReceiver, aHandler)
{
  gRefCnt++;
  if (gRefCnt == 1) {
    kInputAtom = NS_NewAtom("input");
    kSelectAtom = NS_NewAtom("select");
    kChangeAtom = NS_NewAtom("change");
    kSubmitAtom = NS_NewAtom("submit");
    kResetAtom = NS_NewAtom("reset");
  }
}

nsXBLFormHandler::~nsXBLFormHandler()
{
  gRefCnt--;
  if (gRefCnt == 0) {
    NS_RELEASE(kInputAtom);
    NS_RELEASE(kSubmitAtom);
    NS_RELEASE(kResetAtom);
    NS_RELEASE(kSelectAtom);
    NS_RELEASE(kChangeAtom);
  }
}

NS_IMPL_ISUPPORTS_INHERITED1(nsXBLFormHandler, nsXBLEventHandler, nsIDOMFormListener)

nsresult nsXBLFormHandler::Submit(nsIDOMEvent* aEvent)
{
  return DoGeneric(kSubmitAtom, aEvent);
}

nsresult nsXBLFormHandler::Reset(nsIDOMEvent* aEvent)
{
  return DoGeneric(kResetAtom, aEvent);
}

nsresult nsXBLFormHandler::Select(nsIDOMEvent* aEvent)
{
  return DoGeneric(kSelectAtom, aEvent);
}

nsresult nsXBLFormHandler::Change(nsIDOMEvent* aEvent)
{
  return DoGeneric(kChangeAtom, aEvent);
}

nsresult nsXBLFormHandler::Input(nsIDOMEvent* aEvent)
{
  return DoGeneric(kInputAtom, aEvent);
}

///////////////////////////////////////////////////////////////////////////////////

nsresult
NS_NewXBLFormHandler(nsIDOMEventReceiver* aRec,
                     nsXBLPrototypeHandler* aHandler,
                     nsXBLFormHandler** aResult)
{
  *aResult = new nsXBLFormHandler(aRec, aHandler);
  if (!*aResult)
    return NS_ERROR_OUT_OF_MEMORY;
  NS_ADDREF(*aResult);
  return NS_OK;
}

==> mozilla-source-1.4.4.tar.bz2: mozilla/content/xbl/src/nsXBLFormHandler.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Original Author: David W. Hyatt (hyatt@netscape.com)
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsCOMPtr.h"
#include "nsXBLPrototypeHandler.h"
#include "nsXBLFormHandler.h"
#include "nsXBLAtoms.h"
#include "nsIContent.h"
#include "nsIScriptContext.h"
#include "nsIScriptGlobalObject.h"
#include "nsIDocument.h"
#include "nsIDOMDocument.h"
#include "nsIEventListenerManager.h"
#include "nsIDOMEventReceiver.h"
#include "nsXBLBinding.h"
#include "nsIPrivateDOMEvent.h"
#include "nsIDOMWindowInternal.h"
#include "nsIServiceManager.h"
#include "nsIURI.h"
#include "nsXPIDLString.h"

nsXBLFormHandler::nsXBLFormHandler(nsIDOMEventReceiver* aReceiver,
                                   nsXBLPrototypeHandler* aHandler)
  : nsXBLEventHandler(aReceiver, aHandler)
{
}

nsXBLFormHandler::~nsXBLFormHandler()
{
}

NS_IMPL_ISUPPORTS_INHERITED1(nsXBLFormHandler, nsXBLEventHandler, nsIDOMFormListener)

nsresult nsXBLFormHandler::Submit(nsIDOMEvent* aEvent)
{
  return DoGeneric(nsXBLAtoms::submit, aEvent);
}

nsresult nsXBLFormHandler::Reset(nsIDOMEvent* aEvent)
{
  return DoGeneric(nsXBLAtoms::reset, aEvent);
}

nsresult nsXBLFormHandler::Select(nsIDOMEvent* aEvent)
{
  return DoGeneric(nsXBLAtoms::select, aEvent);
}

nsresult nsXBLFormHandler::Change(nsIDOMEvent* aEvent)
{
  return DoGeneric(nsXBLAtoms::change, aEvent);
}

nsresult nsXBLFormHandler::Input(nsIDOMEvent* aEvent)
{
  return DoGeneric(nsXBLAtoms::input, aEvent);
}

///////////////////////////////////////////////////////////////////////////////////

nsresult
NS_NewXBLFormHandler(nsIDOMEventReceiver* aRec,
                     nsXBLPrototypeHandler* aHandler,
                     nsXBLFormHandler** aResult)
{
  *aResult = new nsXBLFormHandler(aRec, aHandler);
  if (!*aResult)
    return NS_ERROR_OUT_OF_MEMORY;
  NS_ADDREF(*aResult);
  return NS_OK;
}
